@@ -30,6 +30,7 @@ import errno
 from collections import namedtuple
 
 import misc
+from vdsm.password import ProtectedPassword
 from vdsm.config import config
 from vdsm.netinfo import getRouteDeviceTo
 import devicemapper
@@ -151,6 +152,7 @@ def readSessionInfo(sessionID):
             res.append("")
 
     iqn, iface, tpgt, username, password, ip, port, netdev = res
+    password = ProtectedPassword(password)
     port = int(port)
     tpgt = int(tpgt)
 
@@ -158,7 +160,7 @@ def readSessionInfo(sessionID):
     # as "<NULL>" (RHEL5) or "(null)" (RHEL6)
     if username in ["<NULL>", "(null)"]:
         username = None
-    if password in ["<NULL>", "(null)"]:
+    if password.value in ["<NULL>", "(null)"]:
         password = None
 
     if netdev in ["<NULL>", "(null)"]:
@@ -293,15 +295,20 @@ class ChapCredentials(object):
         if self.username is not None:
             res.append(("auth.username", self.username))
         if self.password is not None:
-            res.append(("auth.password", self.password))
+            res.append(("auth.password", self.password.value))
 
         return res
 
     def __eq__(self, other):
-        return hash(self) == hash(other)
+        return (self.__class__ == other.__class__ and
+                self.username == other.username and
+                self.password.value == other.password.value)
+
+    def __ne__(self, other):
+        return not self == other
 
     def __hash__(self):
-        return hash(self.__class__) ^ hash(self.username) ^ hash(self.password)
+        return hash((self.__class__, self.username, self.password.value))
 
 
 # Technically there are a lot more interface properties but VDSM doesn't
